scipy.sparse.dia
================

.. automodule:: scipy.sparse.dia

   
   
   .. rubric:: Functions

   .. autosummary::
   
      dia_matvec
      getdtype
      isshape
      isspmatrix
      isspmatrix_dia
      upcast
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      dia_matrix
   
   

   
   
   